darkhistory.history.tla.get_history — DarkHistory documentation

# darkhistory.history.tla.get_history

`darkhistory.history.tla.` `get_history`(rs_vec, init_cond=None, f_H_ion=None, f_H_exc=None, f_heating=None, dm_injection_rate=None, reion_switch=False, reion_rs=None, photoion_rate_func=None, photoheat_rate_func=None, xe_reion_func=None, helium_TLA=False, f_He_ion=None, mxstep=1000, rtol=0.0001)

  Returns the ionization and thermal history of the IGM.

  Parameters: | init_cond : array, optional Array containing [initial temperature, initial xHII, initial xHeII, initial xHeIII]. Defaults to standard values if None. f_H_ion : function or float, optional f(rs, x_HI, x_HeI, x_HeII) for hydrogen ionization. Treated as constant if float. f_H_exc : function or float, optional f(rs, x_HI, x_HeI, x_HeII) for hydrogen Lyman-alpha excitation. Treated as constant if float. f_heating : function or float, optional f(rs, x_HI, x_HeI, x_HeII) for heating. Treated as constant if float. dm_injection_rate : function or float, optional Injection rate of DM as a function of redshift. Treated as constant if float. rs_vec : ndarray Abscissa for the solution. reion_switch : bool Reionization model included if True. reion_rs : float, optional Redshift 1+z at which reionization effects turn on. photoion_rate_func : tuple of functions, optional Functions take redshift 1+z as input, return the photoionization rate in s^-1 of HI, HeI and HeII respectively. If not specified, defaults to darkhistory.history.reionization.photoion_rate. photoheat_rate_func : tuple of functions, optional Functions take redshift 1+z as input, return the photoheating rate in s^-1 of HI, HeI and HeII respectively. If not specified, defaults to darkhistory.history.reionization.photoheat_rate. xe_reion_func : function, optional Specifies a fixed ionization history after reion_rs. helium_TLA : bool, optional Specifies whether to track helium before reionization. f_He_ion : function or float, optional f(rs, x_HI, x_HeI, x_HeII) for helium ionization. Treated as constant if float. If None, treated as zero. mxstep : int, optional The maximum number of steps allowed for each integration point. See scipy.integrate.odeint for more information. rtol : float, optional The relative error of the solution. See scipy.integrate.odeint for more information.
  Returns: | list of ndarray [temperature solution (in eV), xHII solution, xHeII, xHeIII].

  Notes

  The actual differential equation that we solve is expressed in terms of y = arctanh(f*(x - f)), where f = 0.5 for x = xHII, and f = nHe/nH * 0.5 for x = xHeII or xHeIII, where nHe/nH is approximately 0.083.

#### Previous topic

darkhistory.history.tla.compton_cooling_rate

#### Next topic

darkhistory.low_energy

### This Page

Show Source